# coding=utf-8
# Licensed Materials - Property of IBM
# Copyright IBM Corp. 2018

"""
Overview
++++++++

Provides functions to run SQL statements to a database.

Use this package with the following services on IBM Cloud:

  * `Streaming Analytics <https://www.ibm.com/cloud/streaming-analytics>`_
  * `Db2 Warehouse <https://www.ibm.com/cloud/db2-warehouse-on-cloud>`_


Credentials
+++++++++++

Db2 Warehouse credentials are defined using service credentials JSON.

Sample
++++++

A simple hello world example of a Streams application that creates a table, inserts a row and deletes the table::

    from streamsx.topology.topology import *
    from streamsx.topology.schema import CommonSchema, StreamSchema
    from streamsx.topology.context import submit
    import streamsx.database as db

    topo = Topology()
    sql_create = 'CREATE TABLE RUN_SAMPLE (A CHAR(10), B CHAR(10))'
    sql_insert = 'INSERT INTO RUN_SAMPLE (A, B) VALUES (\'hello\', \'world\')'
    sql_drop = 'DROP TABLE RUN_SAMPLE'
    s = topo.source([sql_create, sql_insert, sql_drop]).as_string()
    res_sql = db.run_statement(s, credentials)
    res_sql.print()
    submit('STREAMING_ANALYTICS_SERVICE', topo)


"""

__all__ = ['run_statement']
from streamsx.database._database import run_statement
